@@ -80,7 +80,7 @@ def iva_l_sos(X, whiten=True, grad_projection=False, verbose=False, A=None, W_in
         if True, the non-colinear direction is normalized
 
     verbose : bool, optional
-         enables print statements if True. Automatically set to True if A is provided
+         enables print statements if True
 
     A : np.ndarray, optional
          true mixing matrices A of dimensions N x N x K, automatically sets verbose to True
@@ -242,9 +242,6 @@ def iva_l_sos(X, whiten=True, grad_projection=False, verbose=False, A=None, W_in
                 W[:, :, k] = np.linalg.solve(sc.linalg.sqrtm(W[:, :, k] @ W[:, :, k].T), W[:, :, k])
 
     if supply_A:
-        # only reason to supply A matrices is to display running performance and to compute
-        # output_isi
-        verbose = True
         isi = np.zeros(max_iter)
         if whiten:
             # A matrix is conditioned by V if data is whitened
@@ -380,7 +377,9 @@ def iva_l_sos(X, whiten=True, grad_projection=False, verbose=False, A=None, W_in
     W, Sigma_N = _resort_scvs(W, R_xx, whiten, V)
 
     end = time.time()
-    print(f"IVA-L-SOS finished after {(end - start) / 60} minutes with {iteration} iterations.")
+
+    if verbose:
+        print(f"IVA-L-SOS finished after {(end - start) / 60} minutes with {iteration} iterations.")
 
     if return_W_change:
         return W, cost, Sigma_N, isi, W_change
